starcluster

Package starcluster |
[hide private]
[frames] | no frames]

# Source Code for Package starcluster

     1  import sys
     2  from starcluster import static
     3  sys.path.insert(0, static.STARCLUSTER_PLUGIN_DIR)
     4
     5  __version__ = static.VERSION
     6  __author__ = "Justin Riley (justin.t.riley@gmail.com)"
     7  __all__ = [
     8      "config",
     9      "static",
    10      "cluster",
    11      "clustersetup",
    12      "node",
    13      "ssh",
    14      "plugins",
    15      "balancers",
    16      "managers",
    17      "image",
    18      "volume",
    19      "awsutils",
    20      "cli",
    21      "commands",
    22      "logger",
    23      "utils",
    24      "iptools",
    25      "threadpool",
    26      "templates",
    27      "exception",
    28      "tests",
    29      "optcomplete",
    30      "progressbar",
    31      "spinner",
    32  ]
    33
    34
    35 -def test():
    36      try:
    37          from nose.core import TestProgram
    38          TestProgram(argv=[__file__, "starcluster.tests", '-s'], exit=False)
    39      except ImportError:
    40          print 'error importing nose'
    41
    42  test.__test__ = False
    43